@@ -2,8 +2,7 @@ context("qtlRaster")
 library(assignR)
 data("naMap")
 data("d2h_world")
-d = subOrigData(taxon = "Homo sapiens", 
-                reference = "Ehleringer et al. 2008", mask = naMap)
+d = subOrigData(taxon = "Homo sapiens", dataset = 10, mask = naMap)
 r = calRaster(known = d, isoscape = d2h_world, mask = naMap)
 id = c("A", "B", "C", "D")
 d2H = c(-110, -90, -105, -102)
